@@ -27,14 +27,19 @@
 #include "singleton.h"
 #include "constants.h"
 
-#include <com_deepin_daemon_display.h>
-
-using DisplayInter = com::deepin::daemon::Display;
 using namespace Dock;
 
 class QScreen;
 class QTimer;
 class QGSettings;
+/**
+ * @brief The DisplayManager class
+ * @note    1、对QScreen信息的获取和监听进行了封装，不应该在此程序的其他处再出现类似的代码，而是从当前实例中进行提供
+ * @note    2、对显示相关数据的读写尽可能通过Qt库进行，而不是通过一些DBus服务，
+ * @note       目的一是为了解耦
+ * @note       二是DBus服务的稳定性较低，有部分问题存在
+ * @note       三是DBus服务(特指Display相关)刚开始的目的是为了做一些架构和特殊机器的兼容适配工作，因为qt适配开展较慢，所以才有了DBus服务的存在，目前qt已足够稳定，我们不应该再大量使用后端提供的Display服务
+ */
 class DisplayManager: public QObject, public Singleton<DisplayManager>
 {
     Q_OBJECT
@@ -60,15 +65,16 @@ private Q_SLOTS:
     void onGSettingsChanged(const QString &key);
 
 Q_SIGNALS:
-    void primaryScreenChanged();
+    void primaryScreenChanged(QScreen *s);
     void screenInfoChanged();       // 屏幕信息发生变化，需要调整任务栏显示，只需要这一个信号，其他的都不要，简化流程
+    void screenAdded(QScreen *s);
+    void screenRemoved(QScreen *s);
 
 private:
     QList<QScreen *> m_screens;
     QMap<QScreen *, QMap<Position, bool>> m_screenPositionMap;
     const QGSettings *m_gsettings;              // 多屏配置控制
     bool m_onlyInPrimary;
-    DisplayInter *m_displayInter;
 };
 
 #endif // DISPLAYMANAGER_H
