@@ -221,10 +221,9 @@ void DatetimePlugin::updateCurrentTimeString()
 {
     const QDateTime currentDateTime = QDateTime::currentDateTime();
 
-    if (m_centralWidget->is24HourFormat())
-        m_dateTipsLabel->setText(currentDateTime.date().toString(Qt::SystemLocaleLongDate) + currentDateTime.toString(" HH:mm:ss"));
-    else
-        m_dateTipsLabel->setText(currentDateTime.date().toString(Qt::SystemLocaleLongDate) + currentDateTime.toString(" hh:mm:ss A"));
+    // 实时刷新日期，防止日期显示错误
+    m_centralWidget->updateDateTimeString();
+    m_dateTipsLabel->setText(m_centralWidget->getDateTime());
 
     const QString currentString = currentDateTime.toString("yyyy/MM/dd hh:mm");
 
