@@ -162,7 +162,7 @@ void SoundApplet::initUi()
     m_soundShow->setForegroundRole(QPalette::BrightText);
     DFontSizeManager::instance()->bind(m_soundShow, DFontSizeManager::T8, QFont::Medium);
 
-    m_deviceLabel->setText(tr("Device"));
+    m_deviceLabel->setText(tr("Volume"));
     m_deviceLabel->setFixedHeight(TITLE_HEIGHT);
     m_deviceLabel->setForegroundRole(QPalette::BrightText);
     DFontSizeManager::instance()->bind(m_deviceLabel, DFontSizeManager::T4, QFont::Medium);
@@ -285,7 +285,7 @@ void SoundApplet::onDefaultSinkChanged()
 
     connect(m_defSinkInter, &DBusSink::VolumeChanged, this, &SoundApplet::onVolumeChanged);
     connect(m_defSinkInter, &DBusSink::MuteChanged, this, [ = ] {
-        onVolumeChanged(m_defSinkInter->volume());
+        onVolumeChanged(existActiveOutputDevice() ? m_defSinkInter->volume() : 0);
     });
 
     QString portId = m_defSinkInter->activePort().name;
@@ -297,7 +297,8 @@ void SoundApplet::onDefaultSinkChanged()
     activePort(portId,cardId);
 
     //无声卡状态下，会有伪sink设备，显示音量为0
-    onVolumeChanged(findPort(portId, cardId) != nullptr ? m_defSinkInter->volume() : 0);
+    //支持云平台无声卡显示
+    onVolumeChanged(existActiveOutputDevice() ? m_defSinkInter->volume() : 0);
     emit defaultSinkChanged(m_defSinkInter);
 }
 
@@ -641,7 +642,8 @@ bool SoundApplet::existActiveOutputDevice()
         }
     }
 
-    return false;
+    // 兼容云平台无端口的情况
+    return jCards.isEmpty() && m_defSinkInter && !m_defSinkInter->name().startsWith("auto_null");
 }
 
 bool SoundApplet::eventFilter(QObject *watcher, QEvent *event)
