@@ -121,6 +121,69 @@
         <translation>Ρυθμίσεις ώρας </translation>
     </message>
 </context>
+<context>
+    <name>DatetimeWidget</name>
+    <message>
+        <source>Monday</source>
+        <translation>Δευτέρα</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>Τρίτη</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>Τετάρτη</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>Πέμπτη</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>Παρασκευή</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>Σάββατο</translation>
+    </message>
+    <message>
+        <source>Sunday</source>
+        <translation>Κυριακή</translation>
+    </message>
+    <message>
+        <source>monday</source>
+        <translation>Δευτέρα</translation>
+    </message>
+    <message>
+        <source>tuesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>wednesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>thursday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>friday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>saturday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>sunday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>%1year%2month%3day</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -248,14 +311,20 @@
     <message>
         <source>Size</source>
         <translation>Μέγεθος</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Multiple Displays</source>
         <translation>Πολλαπλές Οθόνες</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Plugin Area</source>
         <translation type="unfinished"/>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Select which icons appear in the Dock</source>
@@ -272,6 +341,8 @@
     <message>
         <source>Mode</source>
         <translation>Λειτουργία</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Top</source>
@@ -292,6 +363,8 @@
     <message>
         <source>Location</source>
         <translation>Τοποθεσία</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Keep shown</source>
@@ -308,6 +381,8 @@
     <message>
         <source>Status</source>
         <translation>Κατάσταση</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Small</source>
@@ -400,7 +475,30 @@
     <message>
         <source>Dock</source>
         <translation>Προσθήκη στην γραμμή εργασιών</translation>
-        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>Λειτουργία</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Τοποθεσία</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>Κατάσταση</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Μέγεθος</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -456,8 +554,8 @@
 <context>
     <name>SoundApplet</name>
     <message>
-        <source>Device</source>
-        <translation>Συσκευή</translation>
+        <source>Volume</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -478,6 +576,10 @@
         <source>Volume %1</source>
         <translation>Ένταση %1</translation>
     </message>
+    <message>
+        <source>No output devices</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>SoundPlugin</name>
