@@ -121,6 +121,69 @@
         <translation>Idő beállításai</translation>
     </message>
 </context>
+<context>
+    <name>DatetimeWidget</name>
+    <message>
+        <source>Monday</source>
+        <translation>Hétfő</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>Kedd</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>Szerda</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>Csütörtök</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>Péntek</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>Szombat</translation>
+    </message>
+    <message>
+        <source>Sunday</source>
+        <translation>Vasárnap</translation>
+    </message>
+    <message>
+        <source>monday</source>
+        <translation>Hétfő</translation>
+    </message>
+    <message>
+        <source>tuesday</source>
+        <translation>Kedd</translation>
+    </message>
+    <message>
+        <source>wednesday</source>
+        <translation>Szerda</translation>
+    </message>
+    <message>
+        <source>thursday</source>
+        <translation>Csütörtök</translation>
+    </message>
+    <message>
+        <source>friday</source>
+        <translation>Péntek</translation>
+    </message>
+    <message>
+        <source>saturday</source>
+        <translation>Szombat</translation>
+    </message>
+    <message>
+        <source>sunday</source>
+        <translation>Vasárnap</translation>
+    </message>
+    <message>
+        <source>%1year%2month%3day</source>
+        <translation>% 1év %2 hónap %3 nap</translation>
+    </message>
+</context>
 <context>
     <name>DialogManager</name>
     <message>
@@ -248,14 +311,20 @@
     <message>
         <source>Size</source>
         <translation>Méret</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Multiple Displays</source>
         <translation>Többképernyős mód</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Plugin Area</source>
         <translation>Bővítmény terület</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Select which icons appear in the Dock</source>
@@ -272,6 +341,8 @@
     <message>
         <source>Mode</source>
         <translation>Mód</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Top</source>
@@ -292,6 +363,8 @@
     <message>
         <source>Location</source>
         <translation>Hely</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Keep shown</source>
@@ -308,6 +381,8 @@
     <message>
         <source>Status</source>
         <translation>Állapot</translation>
+        <extra-child_page>Dock</extra-child_page>
+        <extra-contents_path>/personalization/Dock</extra-contents_path>
     </message>
     <message>
         <source>Small</source>
@@ -400,7 +475,30 @@
     <message>
         <source>Dock</source>
         <translation>Dokkoló</translation>
-        <extra-contents_path>/personalization/Dock</extra-contents_path>
+    </message>
+    <message>
+        <source>Mode</source>
+        <translation>Mód</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Hely</translation>
+    </message>
+    <message>
+        <source>Status</source>
+        <translation>Állapot</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Méret</translation>
+    </message>
+    <message>
+        <source>Show Dock</source>
+        <translation>Dokkoló mutatása</translation>
+    </message>
+    <message>
+        <source>Plugin Area</source>
+        <translation>Bővítmény terület</translation>
     </message>
 </context>
 <context>
@@ -456,8 +554,8 @@
 <context>
     <name>SoundApplet</name>
     <message>
-        <source>Device</source>
-        <translation>Eszköz</translation>
+        <source>Volume</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -478,6 +576,10 @@
         <source>Volume %1</source>
         <translation>Hangerő: %1</translation>
     </message>
+    <message>
+        <source>No output devices</source>
+        <translation>Nincsenek kimeneti eszközök</translation>
+    </message>
 </context>
 <context>
     <name>SoundPlugin</name>
